@@ -5,54 +5,85 @@ from typing import List, Optional, Union
 
 import pandas as pd
 from sklearn.pipeline import Pipeline
+from sklearn.utils.multiclass import check_classification_targets, type_of_target
 
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X_y
 from feature_engine.discretisation import DecisionTreeDiscretiser
-from feature_engine.encoding.base_encoder import BaseCategoricalTransformer
+from feature_engine.encoding._docstrings import (
+    _ignore_format_docstring,
+    _variables_docstring,
+)
+from feature_engine.encoding.base_encoder import (
+    CategoricalInitMixin,
+    CategoricalMethodsMixin,
+)
 from feature_engine.encoding.ordinal import OrdinalEncoder
-from feature_engine.variable_manipulation import _check_input_parameter_variables
+from feature_engine.tags import _return_tags
 
 
-class DecisionTreeEncoder(BaseCategoricalTransformer):
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+)
+class DecisionTreeEncoder(CategoricalInitMixin, CategoricalMethodsMixin):
     """
     The DecisionTreeEncoder() encodes categorical variables with predictions
     of a decision tree.
 
-    The encoder first fits a decision tree using a single feature and the target (fit).
-    And  then replaces the values of the original feature by the predictions of the
-    tree (transform). The transformer will train a Decision tree per every feature to
+    The encoder first fits a decision tree using a single feature and the target (fit),
+    and then replaces the values of the original feature by the predictions of the
+    tree (transform). The transformer will train a decision tree per every feature to
     encode.
 
-    The motivation is to try and create monotonic relationships between the categorical
-    variables and the target.
-
-    Under the hood, the categorical variable will be first encoded into integers with
-    the OrdinalCategoricalEncoder(). The integers can be assigned arbitrarily to the
-    categories or following the mean value of the target in each category. Then a
-    decision tree will fit the resulting numerical variable to predict the target
-    variable. Finally, the original categorical variable values will be replaced by the
-    predictions of the decision tree.
-
     The DecisionTreeEncoder() will encode only categorical variables by default
     (type 'object' or 'categorical'). You can pass a list of variables to encode or the
-    encoder will find and encode all categorical variables. But with
-    `ignore_format=True` you have the option to encode numerical variables as well. In
-    this case, you can either enter the list of variables to encode, or the transformer
-    will automatically select all variables.
+    encoder will find and encode all categorical variables.
+
+    With `ignore_format=True` you have the option to encode numerical variables as
+    well. In this case, you can either enter the list of variables to encode, or the
+    transformer will automatically select all variables.
+
+    More details in the :ref:`User Guide <decisiontree_encoder>`.
 
     Parameters
     ----------
     encoding_method: str, default='arbitrary'
-        The categorical encoding method that will be used to encode the original
-        categories to numerical values.
+        The method used to encode the categories to numerical values before fitting the
+        decision tree.
 
-        'ordered': the categories are numbered in ascending order according to
+        **'ordered'**: the categories are numbered in ascending order according to
         the target mean value per category.
 
-        'arbitrary' : categories are numbered arbitrarily.
+        **'arbitrary'** : categories are numbered arbitrarily.
 
-    cv: int, default=3
-        Desired number of cross-validation fold to be used to fit the decision
-        tree.
+    cv: int, cross-validation generator or an iterable, default=3
+        Determines the cross-validation splitting strategy. Possible inputs for cv are:
+
+            - None, to use cross_validate's default 5-fold cross validation
+
+            - int, to specify the number of folds in a (Stratified)KFold,
+
+            - CV splitter
+                - (https://scikit-learn.org/stable/glossary.html#term-CV-splitter)
+
+            - An iterable yielding (train, test) splits as arrays of indices.
+
+        For int/None inputs, if the estimator is a classifier and y is either binary or
+        multiclass, StratifiedKFold is used. In all other cases, KFold is used. These
+        splitters are instantiated with `shuffle=False` so the splits will be the same
+        across calls. For more details check Scikit-learn's `cross_validate`'s
+        documentation.
 
     scoring: str, default='neg_mean_squared_error'
         Desired metric to optimise the performance for the decision tree. Comes from
@@ -61,12 +92,10 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
         https://scikit-learn.org/stable/modules/model_evaluation.html
 
     param_grid: dictionary, default=None
-        The list of parameters over which the decision tree should be optimised
-        during the grid search. The param_grid can contain any of the permitted
-        parameters for Scikit-learn's DecisionTreeRegressor() or
-        DecisionTreeClassifier().
-
-        If None, then param_grid = {'max_depth': [1, 2, 3, 4]}.
+        The hyperparameters for the decision tree to test with a grid search. The
+        `param_grid` can contain any of the permitted hyperparameters for Scikit-learn's
+        DecisionTreeRegressor() or DecisionTreeClassifier(). If None, then param_grid
+        will optimise the 'max_depth' over `[1, 2, 3, 4]`.
 
     regression: boolean, default=True
         Indicates whether the encoder should train a regression or a classification
@@ -78,44 +107,37 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
         DecisionTreeClassifier(). For reproducibility it is recommended to set
         the random_state to an integer.
 
-    variables: list, default=None
-        The list of categorical variables that will be encoded. If None, the
-        encoder will find and transform all variables of type object or categorical by
-        default. You can also make the transformer accept numerical variables, see the
-        next parameter.
+    {variables}
 
-    ignore_format: bool, default=False
-        Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
-        object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
-        accept all variables entered by the user, including those cast as numeric.
+    {ignore_format}
 
     Attributes
     ----------
     encoder_:
         sklearn Pipeline containing the ordinal encoder and the decision tree.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Fit a decision tree per variable.
+
+    {fit_transform}
+
     transform:
         Replace categorical variable by the predictions of the decision tree.
-    fit_transform:
-        Fit to the data, then transform it.
 
     Notes
     -----
-    The authors designed this method originally, to work with numerical variables. We
-    can replace numerical variables by the preditions of a decision tree utilising the
-    DecisionTreeDiscretiser().
+    The authors designed this method originally to work with numerical variables. We
+    can replace numerical variables by the predictions of a decision tree utilising the
+    DecisionTreeDiscretiser(). Here we extend this functionality to work also with
+    categorical variables.
 
     NAN are introduced when encoding categories that were not present in the training
     dataset. If this happens, try grouping infrequent categories using the
@@ -139,7 +161,7 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
     def __init__(
         self,
         encoding_method: str = "arbitrary",
-        cv: int = 3,
+        cv=3,
         scoring: str = "neg_mean_squared_error",
         param_grid: Optional[dict] = None,
         regression: bool = True,
@@ -148,16 +170,15 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
         ignore_format: bool = False,
     ) -> None:
 
+        super().__init__(variables, ignore_format)
         self.encoding_method = encoding_method
         self.cv = cv
         self.scoring = scoring
         self.regression = regression
         self.param_grid = param_grid
         self.random_state = random_state
-        self.variables = _check_input_parameter_variables(variables)
-        self.ignore_format = ignore_format
 
-    def fit(self, X: pd.DataFrame, y: Optional[pd.Series] = None):
+    def fit(self, X: pd.DataFrame, y: pd.Series):
         """
         Fit a decision tree per variable.
 
@@ -170,23 +191,23 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
         y : pandas series.
             The target variable. Required to train the decision tree and for
             ordered ordinal encoding.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not a Pandas DataFrame.
-            - f user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            - If there are no categorical variables in the df or the df is empty
-            - If the variable(s) contain null values
-
-        Returns
-        -------
-        self
         """
+        X, y = check_X_y(X, y)
 
-        # check input dataframe
-        X = self._check_fit_input_and_variables(X)
+        # confirm model type and target variables are compatible.
+        if self.regression is True:
+            if type_of_target(y) == "binary":
+                raise ValueError(
+                    "Trying to fit a regression to a binary target is not "
+                    "allowed by this transformer. Check the target values "
+                    "or set regression to False."
+                )
+
+        else:
+            check_classification_targets(y)
+
+        self._check_or_select_variables(X)
+        self._get_feature_names_in(X)
 
         if self.param_grid:
             param_grid = self.param_grid
@@ -198,6 +219,7 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
             encoding_method=self.encoding_method,
             variables=self.variables_,
             ignore_format=self.ignore_format,
+            errors="raise",
         )
 
         # initialize decision tree discretiser
@@ -220,32 +242,20 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
 
         self.encoder_.fit(X, y)
 
-        self.n_features_in_ = X.shape[1]
-
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
         """
-        Replace categorical variable by the predictions of the decision tree.
+        Replace categorical variables by the predictions of the decision tree.
 
         Parameters
         ----------
         X : pandas dataframe of shape = [n_samples, n_features]
             The input samples.
 
-        Raises
-        ------
-        TypeError
-            If the input is not a Pandas DataFrame
-        ValueError
-            - If the variable(s) contain null values
-            - If dataframe is not of same size as that used in fit()
-        Warning
-            If after encoding, NAN were introduced.
-
         Returns
         -------
-        X : pandas dataframe of shape = [n_samples, n_features].
+        X_new : pandas dataframe of shape = [n_samples, n_features].
             Dataframe with variables encoded with decision tree predictions.
         """
 
@@ -258,3 +268,13 @@ class DecisionTreeEncoder(BaseCategoricalTransformer):
     def inverse_transform(self, X: pd.DataFrame):
         """inverse_transform is not implemented for this transformer."""
         return self
+
+    def _more_tags(self):
+        tags_dict = _return_tags()
+        tags_dict["variables"] = "categorical"
+        tags_dict["requires_y"] = True
+        # the below test will fail because sklearn requires to check for inf, but
+        # you can't check inf of categorical data, numpy returns and error.
+        # so we need to leave without this test
+        tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = "transformer allows NA"
+        return tags_dict
