@@ -5,11 +5,41 @@ from typing import List, Union
 
 import pandas as pd
 
-from feature_engine.encoding.base_encoder import BaseCategoricalTransformer
-from feature_engine.variable_manipulation import _check_input_parameter_variables
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+    _variables_attribute_docstring,
+)
+from feature_engine._docstrings.methods import (
+    _fit_transform_docstring,
+    _inverse_transform_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.dataframe_checks import check_X_y
+from feature_engine.encoding._docstrings import (
+    _errors_docstring,
+    _ignore_format_docstring,
+    _transform_docstring,
+    _variables_docstring,
+)
+from feature_engine.encoding.base_encoder import (
+    CategoricalInitExpandedMixin,
+    CategoricalMethodsMixin,
+)
 
 
-class MeanEncoder(BaseCategoricalTransformer):
+@Substitution(
+    ignore_format=_ignore_format_docstring,
+    variables=_variables_docstring,
+    errors=_errors_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+    transform=_transform_docstring,
+    inverse_transform=_inverse_transform_docstring,
+)
+class MeanEncoder(CategoricalInitExpandedMixin, CategoricalMethodsMixin):
     """
     The MeanEncoder() replaces categories by the mean value of the target for each
     category.
@@ -30,42 +60,37 @@ class MeanEncoder(BaseCategoricalTransformer):
     The encoder first maps the categories to the numbers for each variable (fit). The
     encoder then replaces the categories with those numbers (transform).
 
+    More details in the :ref:`User Guide <mean_encoder>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of categorical variables that will be encoded. If None, the
-        encoder will find and transform all variables of type object or categorical by
-        default. You can also make the transformer accept numerical variables, see the
-        next parameter.
+    {variables}
 
-    ignore_format: bool, default=False
-        Whether the format in which the categorical variables are cast should be
-        ignored. If false, the encoder will automatically select variables of type
-        object or categorical, or check that the variables entered by the user are of
-        type object or categorical. If True, the encoder will select all variables or
-        accept all variables entered by the user, including those cast as numeric.
+    {ignore_format}
+
+    {errors}
 
     Attributes
     ----------
     encoder_dict_:
         Dictionary with the target mean value per category per variable.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Learn the target mean value per category, per variable.
-    transform:
-        Encode the categories to numbers.
-    fit_transform:
-        Fit to the data, then transform it.
-    inverse_transform:
-        Encode the numbers into the original categories.
+
+    {fit_transform}
+
+    {inverse_transform}
+
+    {transform}
 
     Notes
     -----
@@ -73,9 +98,14 @@ class MeanEncoder(BaseCategoricalTransformer):
     dataset. If this happens, try grouping infrequent categories using the
     RareLabelEncoder().
 
+    Check also the related transformers in the the open-source package
+    `Category encoders <https://contrib.scikit-learn.org/category_encoders/>`_
+
     See Also
     --------
     feature_engine.encoding.RareLabelEncoder
+    category_encoders.target_encoder.TargetEncoder
+    category_encoders.m_estimate.MEstimateEncoder
 
     References
     ----------
@@ -88,13 +118,10 @@ class MeanEncoder(BaseCategoricalTransformer):
         self,
         variables: Union[None, int, str, List[Union[str, int]]] = None,
         ignore_format: bool = False,
+        errors: str = "ignore",
     ) -> None:
 
-        if not isinstance(ignore_format, bool):
-            raise ValueError("ignore_format takes only booleans True and False")
-
-        self.variables = _check_input_parameter_variables(variables)
-        self.ignore_format = ignore_format
+        super().__init__(variables, ignore_format, errors)
 
     def fit(self, X: pd.DataFrame, y: pd.Series):
         """
@@ -108,25 +135,11 @@ class MeanEncoder(BaseCategoricalTransformer):
 
         y: pandas series
             The target.
-
-        Raises
-        ------
-        TypeError
-            - If the input is not a Pandas DataFrame.
-            - f user enters non-categorical variables (unless ignore_format is True)
-        ValueError
-            - If there are no categorical variables in the df or the df is empty
-            - If the variable(s) contain null values
-
-        Returns
-        -------
-        self
         """
 
-        X = self._check_fit_input_and_variables(X)
-
-        if not isinstance(y, pd.Series):
-            y = pd.Series(y)
+        X, y = check_X_y(X, y)
+        self._check_or_select_variables(X)
+        self._get_feature_names_in(X)
 
         temp = pd.concat([X, y], axis=1)
         temp.columns = list(X.columns) + ["target"]
@@ -138,21 +151,9 @@ class MeanEncoder(BaseCategoricalTransformer):
 
         self._check_encoding_dictionary()
 
-        self.n_features_in_ = X.shape[1]
-
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseCategoricalTransformer.transform.__doc__
-
-    def inverse_transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().inverse_transform(X)
-
-        return X
-
-    inverse_transform.__doc__ = BaseCategoricalTransformer.inverse_transform.__doc__
+    def _more_tags(self):
+        tags_dict = super()._more_tags()
+        tags_dict["requires_y"] = True
+        return tags_dict
