@@ -2,9 +2,19 @@ from typing import List, Union
 
 import pandas as pd
 
-from feature_engine.dataframe_checks import _check_contains_na, _is_dataframe
+from feature_engine.dataframe_checks import _check_contains_na, check_X
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.selection._docstring import (
+    _variables_all_docstring,
+    _variables_attribute_docstring,
+)
 from feature_engine.selection.base_selector import BaseSelector
-from feature_engine.validation import _return_tags
+from feature_engine.tags import _return_tags
 from feature_engine.variable_manipulation import (
     _check_input_parameter_variables,
     _find_all_variables,
@@ -13,61 +23,73 @@ from feature_engine.variable_manipulation import (
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
+@Substitution(
+    confirm_variables=BaseSelector._confirm_variables_docstring,
+    variables=_variables_all_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class DropConstantFeatures(BaseSelector):
     """
-    Drop constant and quasi-constant variables from a dataframe. Constant variables
-    show the same value across all the observations in the dataset. Quasi-constant
-    variables show the same value in almost all the observations in the dataset.
+    DropConstantFeatures() drops constant and quasi-constant variables from a dataframe.
+    Constant variables show the same value in all the observations in the dataset.
+    Quasi-constant variables show the same value in almost all the observations in the
+    dataset.
 
-    By default, DropConstantFeatures() drops only constant variables. This transformer
-    works with both numerical and categorical variables. The user can indicate a list
-    of variables to examine. Alternatively, the transformer will evaluate all the
-    variables in the dataset.
+    This transformer works with numerical and categorical variables. The user can
+    indicate a list of variables to examine. Alternatively, the transformer will
+    evaluate all the variables in the dataset.
 
     The transformer will first identify and store the constant and quasi-constant
     variables. Next, the transformer will drop these variables from a dataframe.
 
+    More details in the :ref:`User Guide <drop_constant>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of variables to evaluate. If None, the transformer will evaluate all
-        variables in the dataset.
+    {variables}
 
     tol: float,int,  default=1
         Threshold to detect constant/quasi-constant features. Variables showing the
         same value in a percentage of observations greater than tol will be considered
         constant / quasi-constant and dropped. If tol=1, the transformer removes
-        constant variables. Else, it will remove quasi-constant variables.
+        constant variables. Else, it will remove quasi-constant variables. For example,
+        if tol=0.98, the transformer will remove variables that show the same value in
+        98% of the observations.
 
     missing_values: str, default=raises
         Whether the missing values should be raised as error, ignored or included as an
-        additional value of the variable, when considering if the feature is constant
-        or quasi-constant. Takes values 'raise', 'ignore', 'include'.
+        additional value of the variable. Takes values 'raise', 'ignore', 'include'.
+
+    {confirm_variables}
 
     Attributes
     ----------
     features_to_drop_:
         List with constant and quasi-constant features.
 
-    variables_:
-        The variables to consider for the feature selection.
+    {variables_}:
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Find constant and quasi-constant features.
+
+    {fit_transform}
+
     transform:
         Remove constant and quasi-constant features.
-    fit_transform:
-        Fit to the data. Then transform it.
 
     Notes
     -----
     This transformer is a similar concept to the VarianceThreshold from Scikit-learn,
-    but it evaluates number of unique values instead of variance
+    but it evaluates number of unique values instead of variance.
 
     See Also
     --------
@@ -75,10 +97,19 @@ class DropConstantFeatures(BaseSelector):
     """
 
     def __init__(
-        self, variables: Variables = None, tol: float = 1, missing_values: str = "raise"
+        self,
+        variables: Variables = None,
+        tol: float = 1,
+        missing_values: str = "raise",
+        confirm_variables: bool = False,
     ):
 
-        if not isinstance(tol, (float, int)) or tol < 0 or tol > 1:
+        if (
+            not isinstance(tol, (float, int))
+            or isinstance(tol, bool)
+            or tol < 0
+            or tol > 1
+        ):
             raise ValueError("tol must be a float or integer between 0 and 1")
 
         if missing_values not in ["raise", "ignore", "include"]:
@@ -86,6 +117,8 @@ class DropConstantFeatures(BaseSelector):
                 "missing_values takes only values 'raise', 'ignore' or " "'include'."
             )
 
+        super().__init__(confirm_variables)
+
         self.tol = tol
         self.variables = _check_input_parameter_variables(variables)
         self.missing_values = missing_values
@@ -100,17 +133,16 @@ class DropConstantFeatures(BaseSelector):
             The input dataframe.
         y: None
             y is not needed for this transformer. You can pass y or None.
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
+
+        # If required exclude variables that are not in the input dataframe
+        self._confirm_variables(X)
 
         # find all variables or check those entered are present in the dataframe
-        self.variables_ = _find_all_variables(X, self.variables)
+        self.variables_ = _find_all_variables(X, self.variables_)
 
         if self.missing_values == "raise":
             # check if dataset contains na
@@ -147,25 +179,16 @@ class DropConstantFeatures(BaseSelector):
                 "constant or quasi-constant features. Try changing the tol value."
             )
 
-        self.n_features_in_ = X.shape[1]
+        # save input features
+        self._get_feature_names_in(X)
 
         return self
 
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseSelector.transform.__doc__
-
     def _more_tags(self):
         tags_dict = _return_tags()
+        tags_dict["allow_nan"] = True
+        tags_dict["variables"] = "all"
         # add additional test that fails
-        tags_dict["_xfail_checks"]["check_estimators_nan_inf"] = "transformer allows NA"
-        tags_dict["_xfail_checks"][
-            "check_fit2d_1feature"
-        ] = "the transformer needs at least 2 columns to compare, ok to fail"
         tags_dict["_xfail_checks"][
             "check_fit2d_1sample"
         ] = "the transformer raises an error when dropping all columns, ok to fail"
