@@ -6,7 +6,21 @@ from sklearn.model_selection import cross_validate
 from feature_engine.dataframe_checks import (
     _check_contains_inf,
     _check_contains_na,
-    _is_dataframe,
+    check_X,
+)
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.substitute import Substitution
+from feature_engine.selection._docstring import (
+    _cv_docstring,
+    _estimator_docstring,
+    _missing_values_docstring,
+    _scoring_docstring,
+    _variables_attribute_docstring,
+    _variables_numerical_docstring,
 )
 from feature_engine.selection.base_selector import BaseSelector
 from feature_engine.variable_manipulation import (
@@ -17,6 +31,18 @@ from feature_engine.variable_manipulation import (
 Variables = Union[None, int, str, List[Union[str, int]]]
 
 
+@Substitution(
+    estimator=_estimator_docstring,
+    scoring=_scoring_docstring,
+    cv=_cv_docstring,
+    confirm_variables=BaseSelector._confirm_variables_docstring,
+    variables=_variables_numerical_docstring,
+    missing_values=_missing_values_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class SmartCorrelatedSelection(BaseSelector):
     """
     SmartCorrelatedSelection() finds groups of correlated features and then selects,
@@ -25,7 +51,7 @@ class SmartCorrelatedSelection(BaseSelector):
     - Feature with least missing values
     - Feature with most unique values
     - Feature with highest variance
-    - Best performing feature according to estimator entered by user
+    - Feature with highest importance according to an estimator
 
     SmartCorrelatedSelection() returns a dataframe containing from each group of
     correlated features, the selected variable, plus all original features that were
@@ -37,96 +63,81 @@ class SmartCorrelatedSelection(BaseSelector):
     variables will need to be encoded to numerical or will be excluded from the
     analysis.
 
+    More details in the :ref:`User Guide <smart_correlation>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of variables to evaluate. If None, the transformer will evaluate all
-        numerical variables in the dataset.
+    {variables}
 
     method: string or callable, default='pearson'
         Can take 'pearson', 'spearman', 'kendall' or callable. It refers to the
         correlation method to be used to identify the correlated features.
 
-        - pearson : standard correlation coefficient
-        - kendall : Kendall Tau correlation coefficient
-        - spearman : Spearman rank correlation
+        - 'pearson': standard correlation coefficient
+        - 'kendall': Kendall Tau correlation coefficient
+        - 'spearman': Spearman rank correlation
         - callable: callable with input two 1d ndarrays and returning a float.
 
-        For more details on this parameter visit the  `pandas.corr()` documentation.
+        For more details on this parameter visit the `pandas.corr()` documentation.
 
     threshold: float, default=0.8
         The correlation threshold above which a feature will be deemed correlated with
         another one and removed from the dataset.
 
-    missing_values: str, default=ignore
-        Takes values 'raise' and 'ignore'. Whether the missing values should be raised
-        as error or ignored when determining correlation.
+    {missing_values}
 
     selection_method: str, default= "missing_values"
         Takes the values "missing_values", "cardinality", "variance" and
         "model_performance".
 
-        "missing_values": keeps the feature from the correlated group with least
+        **"missing_values"**: keeps the feature from the correlated group with least
         missing observations
 
-        "cardinality": keeps the feature from the correlated group with the highest
+        **"cardinality"**: keeps the feature from the correlated group with the highest
         cardinality.
 
-        "variance": keeps the feature from the correlated group with the highest
+        **"variance"**: keeps the feature from the correlated group with the highest
         variance.
 
-        "model_performance": trains a machine learning model using the correlated
+        **"model_performance"**: trains a machine learning model using the correlated
         feature group and retains the feature with the highest importance.
 
-    estimator: object, default = None
-        A Scikit-learn estimator for regression or classification.
+    {estimator}
 
-    scoring: str, default='roc_auc'
-        Desired metric to optimise the performance of the estimator. Comes from
-        sklearn.metrics. See the model evaluation documentation for more options:
-        https://scikit-learn.org/stable/modules/model_evaluation.html
+    {scoring}
 
-    cv: int, cross-validation generator or an iterable, default=3
-        Determines the cross-validation splitting strategy. Possible inputs for cv are:
+    {cv}
 
-            - None, to use cross_validate's default 5-fold cross validation
-
-            - int, to specify the number of folds in a (Stratified)KFold,
-
-            - CV splitter
-                - (https://scikit-learn.org/stable/glossary.html#term-CV-splitter)
-
-            - An iterable yielding (train, test) splits as arrays of indices.
-
-        For int/None inputs, if the estimator is a classifier and y is either binary or
-        multiclass, StratifiedKFold is used. In all other cases, Fold is used. These
-        splitters are instantiated with shuffle=False so the splits will be the same
-        across calls.
-
-        For more details check Scikit-learn's cross_validate documentation
+    {confirm_variables}
 
     Attributes
     ----------
     correlated_feature_sets_:
-        Groups of correlated features.  Each list is a group of correlated features.
+        Groups of correlated features. Each list is a group of correlated features.
 
     features_to_drop_:
         The correlated features to remove from the dataset.
 
-    variables_:
-        The variables to consider for the feature selection.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
-        Find best feature from each correlated groups.
+        Find best feature from each correlated group.
+
+    {fit_transform}
+
     transform:
         Return selected features.
-    fit_transform:
-        Fit to the data. Then transform it.
+
+    Notes
+    -----
+    For brute-force correlation selection, check Feature-engine's
+    DropCorrelatedFeatures().
 
     See Also
     --------
@@ -144,6 +155,7 @@ class SmartCorrelatedSelection(BaseSelector):
         estimator=None,
         scoring: str = "roc_auc",
         cv=3,
+        confirm_variables: bool = False,
     ):
         if not isinstance(threshold, float) or threshold < 0 or threshold > 1:
             raise ValueError("threshold must be a float between 0 and 1")
@@ -176,6 +188,8 @@ class SmartCorrelatedSelection(BaseSelector):
                 "with NaN by setting missing_values to 'ignore."
             )
 
+        super().__init__(confirm_variables)
+
         self.variables = _check_input_parameter_variables(variables)
         self.method = method
         self.threshold = threshold
@@ -197,17 +211,19 @@ class SmartCorrelatedSelection(BaseSelector):
 
         y: pandas series. Default = None
             y is needed if selection_method == 'model_performance'.
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = _is_dataframe(X)
+        X = check_X(X)
+
+        # If required exclude variables that are not in the input dataframe
+        self._confirm_variables(X)
 
         # find all numerical variables or check those entered are in the dataframe
-        self.variables_ = _find_or_check_numerical_variables(X, self.variables)
+        self.variables_ = _find_or_check_numerical_variables(X, self.variables_)
+
+        # check that there are more than 1 variable to select from
+        self._check_variable_number()
 
         if self.missing_values == "raise":
             # check if dataset contains na
@@ -274,18 +290,21 @@ class SmartCorrelatedSelection(BaseSelector):
         # select the feature with least missing values
         if self.selection_method == "missing_values":
             for feature_group in self.correlated_feature_sets_:
+                feature_group = list(feature_group)  # type: ignore
                 f = X[feature_group].isnull().sum().sort_values(ascending=True).index[0]
                 _selected_features.append(f)
 
         # select the feature with most unique values
         elif self.selection_method == "cardinality":
             for feature_group in self.correlated_feature_sets_:
+                feature_group = list(feature_group)  # type: ignore
                 f = X[feature_group].nunique().sort_values(ascending=False).index[0]
                 _selected_features.append(f)
 
         # select the feature with biggest variance
         elif self.selection_method == "variance":
             for feature_group in self.correlated_feature_sets_:
+                feature_group = list(feature_group)  # type: ignore
                 f = X[feature_group].std().sort_values(ascending=False).index[0]
                 _selected_features.append(f)
 
@@ -317,14 +336,7 @@ class SmartCorrelatedSelection(BaseSelector):
             f for f in self.variables_ if f not in _selected_features
         ]
 
-        self.n_features_in_ = X.shape[1]
+        # save input features
+        self._get_feature_names_in(X)
 
         return self
-
-    # Ugly work around to import the docstring for Sphinx, otherwise not necessary
-    def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        X = super().transform(X)
-
-        return X
-
-    transform.__doc__ = BaseSelector.transform.__doc__
