@@ -7,9 +7,24 @@ import pandas as pd
 import scipy.stats as stats
 
 from feature_engine.base_transformers import BaseNumericalTransformer
+from feature_engine._docstrings.methods import _fit_transform_docstring
+from feature_engine._docstrings.fit_attributes import (
+    _variables_attribute_docstring,
+    _feature_names_in_docstring,
+    _n_features_in_docstring,
+)
+from feature_engine._docstrings.class_inputs import _variables_numerical_docstring
+from feature_engine._docstrings.substitute import Substitution
 from feature_engine.variable_manipulation import _check_input_parameter_variables
 
 
+@Substitution(
+    variables=_variables_numerical_docstring,
+    variables_=_variables_attribute_docstring,
+    feature_names_in_=_feature_names_in_docstring,
+    n_features_in_=_n_features_in_docstring,
+    fit_transform=_fit_transform_docstring,
+)
 class YeoJohnsonTransformer(BaseNumericalTransformer):
     """
     The YeoJohnsonTransformer() applies the Yeo-Johnson transformation to the
@@ -25,35 +40,40 @@ class YeoJohnsonTransformer(BaseNumericalTransformer):
     transformer will automatically select and transform all numerical
     variables.
 
+    More details in the :ref:`User Guide <yeojohnson>`.
+
     Parameters
     ----------
-    variables: list, default=None
-        The list of numerical variables to transform. If None, the transformer will
-        automatically find and select all numerical variables.
+    {variables}
 
     Attributes
     ----------
     lambda_dict_
         Dictionary containing the best lambda for the Yeo-Johnson per variable.
 
-    variables_:
-        The group of variables that will be transformed.
+    {variables_}
 
-    n_features_in_:
-        The number of features in the train set used in fit.
+    {feature_names_in_}
+
+    {n_features_in_}
 
     Methods
     -------
     fit:
         Learn the optimal lambda for the Yeo-Johnson transformation.
+
+    {fit_transform}
+
     transform:
         Apply the Yeo-Johnson transformation.
-    fit_transform:
-        Fit to data, then transform it.
 
     References
     ----------
-    .. [1] Weisberg S. "Yeo-Johnson Power Transformations".
+    .. [1] Yeo, In-Kwon and Johnson, Richard (2000).
+       A new family of power transformations to improve normality or symmetry.
+       Biometrika, 87, 954-959.
+
+    .. [2] Weisberg S. "Yeo-Johnson Power Transformations".
         https://www.stat.umn.edu/arc/yjpower.pdf
     """
 
@@ -75,34 +95,16 @@ class YeoJohnsonTransformer(BaseNumericalTransformer):
 
         y: pandas Series, default=None
             It is not needed in this transformer. You can pass y or None.
-
-        Raises
-        ------
-         TypeError
-            - If the input is not a Pandas DataFrame
-            - If any of the user provided variables are not numerical
-        ValueError
-            - If there are no numerical variables in the df or the df is empty
-            - If the variable(s) contain null values
-
-        Returns
-        -------
-        self
         """
 
         # check input dataframe
-        X = super().fit(X)
+        X = super()._fit_from_varlist(X)
 
         self.lambda_dict_ = {}
 
-        # to avoid NumPy error
-        X[self.variables_] = X[self.variables_].astype("float")
-
         for var in self.variables_:
             _, self.lambda_dict_[var] = stats.yeojohnson(X[var])
 
-        self.n_features_in_ = X.shape[1]
-
         return self
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
@@ -114,14 +116,6 @@ class YeoJohnsonTransformer(BaseNumericalTransformer):
         X: Pandas DataFrame of shape = [n_samples, n_features]
             The data to be transformed.
 
-        Raises
-        ------
-        TypeError
-            If the input is not a Pandas DataFrame
-        ValueError
-            - If the variable(s) contain null values
-            - If the df has different number of features than the df used in fit()
-
         Returns
         -------
         X: pandas dataframe
