@@ -1,6 +1,5 @@
 import pandas as pd
 import pytest
-from sklearn.exceptions import NotFittedError
 
 from feature_engine.encoding import WoEEncoder
 
@@ -80,21 +79,31 @@ def test_automatically_select_variables(df_enc):
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]])
 
 
-def test_error_target_is_not_passed(df_enc):
-    # test case 2: raises error if target is  not passed
-    encoder = WoEEncoder(variables=None)
-    with pytest.raises(TypeError):
-        encoder.fit(df_enc)
-
-
 def test_warn_if_transform_df_contains_categories_not_seen_in_fit(df_enc, df_enc_rare):
     # test case 3: when dataset to be transformed contains categories not present
     # in training dataset
-    encoder = WoEEncoder(variables=None)
-    with pytest.warns(UserWarning):
+    msg = "During the encoding, NaN values were introduced in the feature(s) var_A."
+
+    # check for error when rare_labels equals 'raise'
+    with pytest.warns(UserWarning) as record:
+        encoder = WoEEncoder(errors="ignore")
         encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
         encoder.transform(df_enc_rare[["var_A", "var_B"]])
 
+    # check that only one warning was raised
+    assert len(record) == 1
+    # check that the message matches
+    assert record[0].message.args[0] == msg
+
+    # check for error when rare_labels equals 'raise'
+    with pytest.raises(ValueError) as record:
+        encoder = WoEEncoder(errors="raise")
+        encoder.fit(df_enc[["var_A", "var_B"]], df_enc["target"])
+        encoder.transform(df_enc_rare[["var_A", "var_B"]])
+
+    # check that the error message matches
+    assert str(record.value) == msg
+
 
 def test_error_if_target_not_binary():
     # test case 4: the target is not binary
@@ -140,13 +149,6 @@ def test_error_if_denominator_probability_is_zero():
     # #     encoder.fit(df[['var_A', 'var_B']], df['target'])
 
 
-def test_non_fitted_error(df_enc):
-    # test case 8: non fitted error
-    with pytest.raises(NotFittedError):
-        imputer = WoEEncoder()
-        imputer.transform(df_enc)
-
-
 def test_error_if_contains_na_in_fit(df_enc_na):
     # test case 9: when dataset contains na, fit method
     encoder = WoEEncoder(variables=None)
@@ -292,3 +294,8 @@ def test_variables_cast_as_category(df_enc_category_dtypes):
 
     pd.testing.assert_frame_equal(X, transf_df[["var_A", "var_B"]], check_dtype=False)
     assert X["var_A"].dtypes == float
+
+
+def test_error_if_rare_labels_not_permitted_value():
+    with pytest.raises(ValueError):
+        WoEEncoder(errors="empanada")
